# Interim workflow for personal certificates

This page describes the current (interim) process to get a personal certificate to sign
documents and sign/decrypt emails.

This service uses the [GÉANT TCS project](https://security.geant.org/trusted-certificate-services/){:target="_blank"}
which itself uses the services of [Sectigo](https://www.sectigo.com/){:target="_blank"}.

!!! danger "Don't skip this!"
    Even if you decide to complete this task without reading through these instructions,
    make sure to follow <a href=#p12-encryption-warning>this particular advice</a>.

<a name="request-certificate"></a>
## Request a new certificate

Log in to the [CA-Portal](https://portal.ca.kit.edu){:target="_blank"} with the account owning the
email addresses you want a certificate for. Use the private mode of your browser if
you are already logged in with another account.

### Choose Certificate Type

Personal certificates are bound to an individual person and are only issued for the email addresses of the corresponding
KIT account. Before applying, according to policy, you must identify yourself in person. An identification is
currently valid for ten years. Personal certificates can be recognized by the fact that the "Certificate Name"
(correctly: Common Name) includes the natural name of the owner.

Functional/group certificates are functionally equivalent to personal certificates. They are not bound to an individual person, but may be shared with all users of the associated email mailboxes. Functional certificates
contain only the associated email addresses and no "Certificate Name" (Common Name). You can also use a functional certificate for personal email addresses instead of personal certificates. In this case, identification is not necessary.

!!! danger "Mailing lists"
    Functional certificates cannot be issued for mailing lists (@lists.kit.edu and @listserv.dfn.de) with the current process from Sectigo, as the challenge for this would be sent directly to the list members. If you need such a certificate [please send us an email](mailto:kit-ca-betrieb@scc.kit.edu?subject=TCS%20Certificate%20Request%20for%20mailinglist) to coordinate the process.

Choose `Request` for the desired certificate type:

![](img/ca-portal_en_request_01.png){ width="796" }

### Personal Certificate

If you do not have a valid identification, you cannot apply for a personal certificate:

![](img/ca-portal_en_request_02_personal_no-ident.png){ width="796" }

Choose one of the described options.

If you have valid identification, you can select which email addresses should be added to
the certificate:

![](img/ca-portal_en_request_10_personal_select_email.png){ width="800" }

Now, all data added to the certificate is displayed for proofreading. Choose `Submit` if everything
is correct:

![](img/ca-portal_en_request_20_personal_submit.png){ width="800" }

Follow the instructions in the browser.

### Functional Certificate

Enter all email addresses that should be added to the certificate. Pay attention to the hints given in the portal!

![](img/ca-portal_en_request_10_functional_add_emails.png){ width="800" }

Now, all data that will be added to the certificate is displayed for proofreading. Choose `Submit` if everything
is correct:

![](img/ca-portal_en_request_20_functional_submit.png){ width="800" }

<a name="sectigo-process"></a>
## Navigate the certificate generation process by Sectigo

Please wait until you get an email from Sectigo (the current sender
is `Sectigo Certificate Manager <support@cert-manager.com>`).

!!! tip "Note for applicants who do not have access to the function mailboxes"
    This email is only sent to the email addresses from the application. If you - for example
    as an IT officer - apply for a functional certificate and __don't__ have access to the relevant
    mailboxes, you will no longer be able to manage the process from this point on.
    You can either leave the rest of the process to the users of the functional mailbox or
    ask them to forward the e-mail from Sectigo to you and not to click on any links.

It looks like this:

![](img/tcs_sectigo_personal_certificate_request_email.png){ width="450" }

### Validate yourself (sometimes necessary)

<a name="sectigo-system-requirements"></a>
!!! tip "System Requirements"
    To work reliably, this process requires a desktop operating system with a modern
    web browser that can execute Javascript without restrictions.

<a name="sectigo-link-is-single-use"></a>
!!! warning
    The link from sectigo may only be used once. Make sure to only open it on the
    device where you actually plan to create and save your new certificate.

The link in this mail **may** lead to a page that ask you to verify and enter your
email address. Skip this paragraph it this does not apply to you:

![](img/tcs_sectigo_personal_certificate_request_validate_email_01.png){ width="509" }

If this happens make sure to enter the exact email address
that the initial email was sent to:

![](img/tcs_sectigo_personal_certificate_request_validate_email_02.png){ width="532" }

Entering the correct address will generate a second email like the first one:

![](img/tcs_sectigo_personal_certificate_request_validate_email_response_01.png){ width="450" }

### Open the certificate request form

Open the link in the latest email from Sectigo. You will land on a webpage
similar to this:

![](img/tcs_sectigo_personal_certificate_request_certificate_enrollment_form_01.png){ width="375" }

### Request a certificate

Please keep all settings as shown on the screenshot above (most settings are
readonly or have no effect on the final certificate). Accept the EULA
(only available in English) and press `Submit`.

Your web browser will now generate a new private key and ask Sectigo
to generate a new matching certificate. Both will be downloaded in the next step.

<a name="do-not-interrupt"></a>
!!! warning "Do not interrupt!"
    Please wait patiently for the next page to load. This may take up to ten
    minutes. Unfortunately there is no progress indicator or other "signs of life".
    Please do not close or reload the page. Both will abort the application process
    force you to start all over from the beginning.

Encountering any problems in this step usually results in a loss of the private key
for your new certificate, which renders it unusable. You must then start the process
from the beginning. If the issue persists, please [contact us via e-mail](mailto:kit-ca-betrieb@scc.kit.edu?subject=TCS%20Certificate%20Request%20breaks%20on%20key%20generation).

![](img/tcs_sectigo_personal_certificate_request_certificate_enrollment_form_02.png)

### Download the issued certificate

You will be redirected to this page after your certificate was successfully created:

<a name="p12-encryption-warning"></a>
!!! danger "Extremely important"
    The default setting of **Secure AES256-SHA256** creates lots of problems on most
    platforms including Windows, macOS and iOS. Make sure to change it to
    **Compatible TripleDES-SHA1**.

    [Click here](https://www.ca.kit.edu/p/faq/de/fix-tcs-p12){:target="_blank"} for a
    guide to repair an unusable certificate (currently only available in German).

Change **Secure AES256-SHA256**:

![](img/tcs_sectigo_personal_certificate_request_certificate_enrollment_form_03_secure.png){ width="404" }

to **Compatible TripleDES-SHA1**:

![](img/tcs_sectigo_personal_certificate_request_certificate_enrollment_form_03_compatible.png){ width="404" }

Choose a secure password (use may use [this tool](https://www.cert.kit.edu/p/PasswordGenerator){:target="_blank"}
to generate a proper password) to encrypt your new key and certificate. Press `Download`. This starts a download with
your new certificate and private key ([PKCS12 format](https://en.wikipedia.org/wiki/PKCS_12){:target="_blank"}, usually ends in `.p12` or `.pfx`).

!!! warning
    You may close this page after verifying that your new certificate has been downloaded successfully.
    The certificate's private key exists __only__ in the PKCS12 file that you just downloaded. If you __can not__
    locate the file, the private key is lost forever and you can not use the certificate. In that case, you have to
    start again from the beginning.

<a name="install-certificate"></a>
## Install the issued certificate

The PKCS12 file you just downloaded can usually be imported by double-clicking
(Windows, macOS) or simply importing it in the application's settings dialog (Thunderbird).

## Create a Backup

Backup your certificate/key file and the corresponding password. We strongly urge you to do it **now**, postponing
usually results in never making backups at all.

You will need every key/certificate pair (usually the `.p12` file) for which you have ever received encrypted emails until
you quit working at KIT.

Secure both the certificate file and the password in a way that you can still safely find and read them in the far
future. For security reasons, it is advisable to store both separately from each other.

??? note ":construction: Work in Progress"
    Unfortunately, this section is still somewhat rudimentary & incomplete.

## E-Mail Client Configuration

* [Outlook in Windows](/guides/en/configure_outlook/)
* [macOS & Apple Mail](/guides/en/install_p12_macos/)